<?php
namespace Elementor;
class Webnus_Element_Widgets_Gallery extends \Elementor\Widget_Base {

	/**
	 * Retrieve Gallery widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {

		return 'gallery';
		
	}

	/**
	 * Retrieve Gallery widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {

		return esc_html__( 'Webnus Gallery', 'deep' );

	}

	/**
	 * Retrieve Gallery widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {

		return 'eicon-gallery-grid';

	}

	/**
	 * Set widget category.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget category.
	 */
	public function get_categories() {

		return [ 'webnus' ];

	}

	/**
	 * enqueue JS 
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_script_depends() {
		
		return [ 'deep-gallery', 'deep-gallery-js'];		
		
	}

	/**
	 * Register Gallery widget controls.
	 *
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls() {

        // Content Tab
		$this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__( 'General', 'deep' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
		);
		
		$this->add_control(
			'images',
			[
				'label' 	=> __( 'Choose Images', 'deep' ), 
				'type' 		=> \Elementor\Controls_Manager::GALLERY, 			
			]
		);

		$this->add_control(
			'images_in_row',
			[
				'label' 	=> __( 'items in row', 'deep' ), 
				'type' 		=> \Elementor\Controls_Manager::SELECT, 
				'default' => 'three',
				'options' => [
					'one'   => __( 'One', 'deep' ),
					'two' 	=> __( 'Two', 'deep' ),
					'three' => __( 'Three', 'deep' ),
					'for'   => __( 'For', 'deep' ),
					'five' 	=> __( 'Five', 'deep' ),
					'six' 	=> __( 'Six', 'deep' ),
					'seven' => __( 'Seven', 'deep' ),
					'eight' => __( 'Eight', 'deep' ),
					'nine' 	=> __( 'Nine', 'deep' ),
					'ten' 	=> __( 'Ten', 'deep' ),
				],			
			]
		);

		$this->add_control(
			'img_size',
			[
				'label' => __( 'Image Dimension', 'deep' ),
				'type' 	=> \Elementor\Controls_Manager::IMAGE_DIMENSIONS,
				'description' => __( 'Crop the original image size to any custom size.', 'deep' ),
				'default' => [
					'width'  => '480',
					'height' => '480',
				],
			]
		);
		
        $this->end_controls_section();

		// Class & ID Tab
		$this->start_controls_section(
			'classid_section',
			[
				'label' => __( 'Class & ID', 'deep' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'shortcodeclass',
			[
				'label'	=> esc_html__( 'Extra Class', 'deep' ),
				'type'	=> Controls_Manager::TEXT,
			]
		);

		$this->add_control(
			'shortcodeid',
			[
				'label'	=> esc_html__( 'ID', 'deep' ),
				'type'	=> Controls_Manager::TEXT,
			]
		);

		$this->end_controls_section();

		// Custom css tab
		$this->start_controls_section(
			'custom_css_section',
			[
				'label' => __( 'Custom CSS', 'deep' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'image_padding',
			[
				'label' 	 => __( 'Image padding', 'deep' ),
				'type' 		 => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .deep-gallery-item' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'custom_css',
			[
				'label' => __( 'Custom CSS', 'deep' ),
				'type' => \Elementor\Controls_Manager::CODE,
				'language' => 'css',
				'rows' => 20,
				'show_label' => true,
			]
		);

		$this->end_controls_section();

	}

	/**
	 * Render Gallery widget output on the frontend.
	 *
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {
		
		wp_enqueue_style( 'wn-deep-gallery', DEEP_ASSETS_URL . 'css/frontend/deep-gallery/deep-gallery.css' );		
		wp_enqueue_style( 'wn-deep-lc-lightbox', DEEP_ASSETS_URL . 'css/frontend/lc-lightbox/lc_lightbox.min.css' );		

		
        $settings    = $this->get_settings();
		$image 		 = $settings['images']; 
		$img_in_row  = $settings['images_in_row'];
		$id 		 = !empty( $settings['shortcodeid'] ) ? $settings['shortcodeid'] : ''; 
		$class 		 = !empty( $settings['shortcodeclass'] ) ? $settings['shortcodeclass'] : ''; ?>

		<div class="deep-gallery-wrap <?php esc_attr_e( $class ); ?>" <?php !empty( $id ) ? esc_html_e( 'id=' . $id . '' ) : '' ;?>>
			<div class="deep-gallery">	
				<?php foreach ($image as $imgs) {
					if( $imgs ) {
						if ( !class_exists( 'Wn_Img_Maniuplate' ) ) {
							require_once DEEP_CORE_DIR . 'helper-classes/class_webnus_manuplate.php';
						}
						$rimage = new \Wn_Img_Maniuplate;
						$new_image  = $rimage->m_image( $imgs['id'], $imgs['url'] , $settings['img_size']['width'] , $settings['img_size']['height'] );
				
						echo '<div class="deep-gallery-item deep-gallery-item-' . esc_attr( $img_in_row ) . '">';
							echo '<a class="gallery-item" 
								href="'.$new_image.'" 																							
								data-lcl-thumb="'.$new_image.'">
								<span style="background-image: url('.$new_image.');"></span>
								<i class="wn-icon ti-plus hover-icon"></i>
							</a>';							
						echo '</div>';						
					}
				} ?>
			</div>
		</div>
		
		<?php
		$custom_css = $settings['custom_css'];

		if ( $custom_css != '' ) {
			echo '<style>'. $custom_css .'</style>';
		}
	}
}