<?php
namespace Elementor;
class Webnus_Element_Widgets_Instagram extends \Elementor\Widget_Base {

	/**
	 * Retrieve Alert widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'instagram';
	}

	/**
	 * Retrieve Alert widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Webnus Instagram', 'deep' );
	}

	/**
	 * Retrieve Alert widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-instagram';
	}

	/**
	 * Set widget category.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget category.
	 */
	public function get_categories() {
		return [ 'webnus' ];
	}


	/**
	 * enqueue JS 
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_script_depends() {
		return [ 'wn-instagram' ];
	}


	/**
	 * Register Alert widget controls.
	 *
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__( 'General', 'deep' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
		);
		$this->add_control(
			'type',
			[
				'label' 	=> esc_html__( 'Type', 'deep' ),
				'type' 		=> Controls_Manager::SELECT,
				'default' 	=> 'default',
				'options' 	=> [
					'default'  		=> esc_html__( 'Default', 'deep' ),
					'carousel'  	=> esc_html__( 'Carousel', 'deep' ),
					'grid'  		=> esc_html__( 'Grid', 'deep' ),
				],
			]
		);

		// Access Token
		$this->add_control(
			'token',
			[
				'label' 		=> esc_html__( 'Access Token', 'deep' ),
				'type' 			=> Controls_Manager::TEXT,
				'placeholder' 	=> esc_html__( 'Type your token here', 'deep' ),
			]
		);

		// Username
		$this->add_control(
			'username',
			[
				'label' 		=> esc_html__( 'Username', 'deep' ),
				'type' 			=> Controls_Manager::TEXT,
				'placeholder' 	=> esc_html__( 'Type your username here', 'deep' ),
			]
		);

		// Number of posts
		$this->add_control(
			'postnumber',
			[
				'label'   => esc_html__( 'Number Of Post', 'your-plugin' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 9,
				'min'     => 1,
				'max'     => 30,
				'step'    => 1,
			]
		);

		// Size
		$this->add_control(
			'size',
			[
				'label' 	=> esc_html__( 'Image Size', 'deep' ),
				'type' 		=> Controls_Manager::SELECT,
				'default' 	=> 'thumbnail',
				'options' 	=> [
					'thumbnail'  			=> esc_html__( '150 * 150 px', 'deep' ),
					'low_resolution'  		=> esc_html__( '320 * 320 px', 'deep' ),
					'standard_resolution'  => esc_html__( '480 * 480 px', 'deep' ),
				],
			]
		);

        $this->end_controls_section();

		$this->start_controls_section(
			'classid_section',
			[
				'label' => __( 'Class & ID', 'deep' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'shortcodeclass',
			[
				'label'	=> esc_html__( 'Extra Class', 'deep' ),
				'type'	=> Controls_Manager::TEXT,
			]
		);

		$this->add_control(
			'shortcodeid',
			[
				'label'	=> esc_html__( 'ID', 'deep' ),
				'type'	=> Controls_Manager::TEXT,
			]
		);

		$this->end_controls_section();

		// Custom css tab
		$this->start_controls_section(
			'custom_css_section',
			[
				'label' => __( 'Custom CSS', 'deep' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'custom_css',
			[
				'label' => __( 'Custom CSS', 'deep' ),
				'type' => \Elementor\Controls_Manager::CODE,
				'language' => 'css',
				'rows' => 20,
				'show_label' => true,
			]
		);

		$this->end_controls_section();

	}

	/**
	 * Render Alert widget output on the frontend.
	 *
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {

        $settings 			= $this->get_settings_for_display();
    
		$type 				= $settings['type'];
		$token 				= $settings['token'];
		$username 			= $settings['username'];
		$postnumber 		= $settings['postnumber'];
		$size 				= $settings['size'];

		$count				= !empty($postnumber) ? $postnumber : '9';
		$insta_user			= $username ? $username : '';
		$size				= $size ? $size : 'thumbnail';

        // Class & ID 
        $shortcodeclass 	= $settings['shortcodeclass'] ? $settings['shortcodeclass'] : '';
        $shortcodeid		= $settings['shortcodeid'] ? ' id="' . $settings['shortcodeid'] . '"' : '';

		$out = '';
			
		$out .= '<section class="footer-instagram-bar ' . $shortcodeclass . '"  ' . $shortcodeid . '>';
			/* Follow Text*/
			$out .= '<div class="container">
						<div class="row">
							<div class="footer-instagram-text">
								<h6>' /*. bloginfo('name')*/ . esc_html__( 'Follow on Instagram', 'deep' ) . '</h6>
							</div>
						</div>
					</div>';
			/* Feed */
			echo '<div class="instagram-feed ' . $type . '">';
			$base_url =  "https://api.instagram.com/v1/users/self/media/recent?access_token=" . $token . "&count=" . $count;

			$raw_content = wp_remote_get(esc_url_raw($base_url));
				if(!is_wp_error($raw_content)){
					
					$raw_content = $raw_content['body'];
					$json_insta = json_decode($raw_content);
					if (isset($json_insta->data[0])){
						$id = $json_insta->data[0]->id;
					}
					
					switch ( $type ) :

						case 'default':
							if(!empty($id)){
								$url = "https://api.instagram.com/v1/users/self/media/recent?access_token=" . $token . "&count=" . $count;
								$raw_content = wp_remote_get(esc_url_raw($url));
								$output = '';
								if(!is_wp_error($raw_content)){
									$output .= '<ul>';	
									$raw_content = $raw_content['body'];
									$json_insta = json_decode($raw_content);
									if (isset($json_insta->data[0])){
										foreach($json_insta->data as $data){		
											$output .= '<li><a href="'.esc_url($data->link).'" target="_blank"><img alt="" src="'.esc_url($data->images->$size->url).'"/></a></li>';											
										}
									}
									$output .= '</ul>';	
									echo '' . $output;
								}
							}
						break;

						case 'carousel':			
							if(!empty($id)){
								$url = "https://api.instagram.com/v1/users/self/media/recent?access_token=" . $token . "&count=" . $count;
								$raw_content = wp_remote_get(esc_url_raw($url));
								$output = '';
								if(!is_wp_error($raw_content)){
									$output .= '<div class="instagram-wrap"><div class="owl-carousel-instagram owl-carousel owl-theme" data-instagram_count="1">';	
									$raw_content = $raw_content['body'];
									$json_insta = json_decode($raw_content);
									if (isset($json_insta->data[0])){
										foreach($json_insta->data as $data){		
											$output .= '<a href="'.esc_url($data->link).'" target="_blank"><img alt="" src="'.esc_url($data->images->$size->url).'"/></a>';	
										}
									}
									$output .= '</div></div>';	
									echo '' . $output;
								}
								echo '<div class="instagram-text"><i class="wn-fab wn-fa-instagram"></i> Follow us <a href="http://instagram.com/' . $insta_user . '">@' . $insta_user .  '</a></div>';
							}
						break;

						case 'grid':
							if(!empty($id)){
								$url = "https://api.instagram.com/v1/users/self/media/recent?access_token=" . $token . "&count=" . $count;
								$raw_content = wp_remote_get(esc_url_raw($url));
								$output = '';
								if(!is_wp_error($raw_content)){
									$output .= '<ul>';	
									$raw_content = $raw_content['body'];
									$json_insta = json_decode($raw_content);
									if (isset($json_insta->data[0])){
										foreach($json_insta->data as $data){		
											$output .= '<li><a href="'.esc_url($data->link).'" target="_blank"><img width="'.esc_attr($data->images->$size->width).'" height="'.esc_attr($data->images->$size->height).'" src="'.esc_url($data->images->$size->url).'"/></a></li>';	
										}
									}
									$output .= '</ul>';	
									echo '' . $output;
								}
							}
						break;

					endswitch;
				}
				else esc_html_e('An error has occoured...','deep');

			echo '<div class="clear"></div>';
			echo '</div>';
		$out .= '</section>';
		$custom_css = $settings['custom_css'];

		if ( $custom_css != '' ) {
			echo '<style>'. $custom_css .'</style>';
		}
		echo $out;

	}

}